/***********************************************************************
 * Module:  IXmPlayer.aidl
 * Author:  chadwii
 * Purpose: Defines the Interface IXmPlayer
 ***********************************************************************/
package com.ximalaya.ting.android.opensdk.player.service;

import com.ximalaya.ting.android.opensdk.player.service.IXmDataCallback;
import com.ximalaya.ting.android.opensdk.player.service.IXmPlayerEventDispatcher;
import com.ximalaya.ting.android.opensdk.player.service.IXmAdsEventDispatcher;
import com.ximalaya.ting.android.opensdk.player.service.IXmGetDownloadPlayPathCallback;
import com.ximalaya.ting.android.opensdk.model.PlayableModel;
import com.ximalaya.ting.android.opensdk.model.track.Track;
import com.ximalaya.ting.android.opensdk.model.live.radio.Radio;
import com.ximalaya.ting.android.opensdk.model.live.program.Program;
import com.ximalaya.ting.android.opensdk.model.live.schedule.Schedule;
import com.ximalaya.ting.android.opensdk.model.category.CategoryModel;
import com.ximalaya.ting.android.opensdk.player.service.IXmCustomDataCallBack;
import com.ximalaya.ting.android.opensdk.player.service.IXmMainDataSupportDataCallback;

interface IXmPlayer {
   
   void setProxy(String host, int port,String authorization);
   
   boolean playPre();
   boolean playNext();
   boolean play(int index);
   boolean setPlayIndex(int index);
   boolean startPlay();
   boolean pausePlay();
   boolean stopPlay();
   boolean seekTo(int ms);
   boolean isOnlineSource();
   
   boolean hasPreSound();
   boolean hasNextSound();
   
   int getPlayerStatus();
   int getCurrIndex();
   int getDuration();
   int getPlayCurrPosition();
   boolean isPlaying();
   boolean isAdsActive();
   
   //PlayableModel getCurrSound();
   void updateTrackDownloadUrlInPlayList(inout Track track);
   void updateTrackInPlayList(inout Track track);
   Track getTrack(int index);
   Radio getRadio();
   int getPlaySourceType();
   
   void setPlayMode(String mode);
   String getPlayMode();
   void setPageSize(int pageSize);
   
   void setPlayList(in Map param, in List<Track> list);
   // 因为IPC通信机制限制只能传递1M所以setPlayList暂时只能传递100个超过的话就将其拆分循环插入 ,执行这个函数之前一定要先执行setPlayList
   void addPlayList(in List<Track> list);
   boolean playRadio(in Radio radio);
   //void setProgramList(in List<Program> list);
   //void setScheduleList(in List<Schedule> list);
   
   // position表示第几次请求 ,position从0开始计算
   List<Track> getPlayList(in int position);
   Map getParam();
   
   int getPlayListSize();
   
   void clearPlayCache();
   
   void setNotification(int id, in Notification notification);
   void setAppSecret(String secret);
   
   void registePlayerListener(IXmPlayerEventDispatcher l);
   void unregistePlayerListener(IXmPlayerEventDispatcher l);
   
   void registeAdsListener(IXmAdsEventDispatcher l);
   void unregisteAdsListener(IXmAdsEventDispatcher l);
   
   void setDownloadPlayPathCallback(IXmGetDownloadPlayPathCallback l);
   
   void getNextPlayList();
   void getPrePlayList();
   void setPlayListChangeListener(IXmDataCallback l);
   boolean permutePlayList();
   boolean getPositiveSeq();
   String getCurPlayUrl(); 
   //以下为第三方开发所用 
   void init(String appsecret, String appkey, String packid);
	
   void registeCustomDataCallBack(IXmCustomDataCallBack l);
   
   void unregisteCustomDataCallBack(IXmCustomDataCallBack l);
   
   void setPlayModel(String modelName ,int categoryId);
   
   void getSourseLists(String query,int categoryId, int page ,int count ,int type);
   
   void browseAlbums(long albumId ,int page ,int count);
   
   void setPlayByTrack(String track);	
   
   void setPlayByAlbumTracks(String CommonTrackList, int position);
	
   void setCategoryId(int categoryId);
   
   void getCategoryModelList();
   
   void getHotContent(boolean isTrack ,int page ,int count);
   
   void getTrackListByLastTrack(long albumId ,long trackId ,int pageCount);
      
   // 主app的aidl通信
   void registeMainDataSupportCallBack(IXmMainDataSupportDataCallback l);
   
   void unregisteMainDataSupportCallBack(IXmMainDataSupportDataCallback l);
   
   void getUserInfo(long key);
   
   void getMyCollect(int page ,long key);
   
   void getAlbumInfo(long albumId ,int page ,long randomkey);
   
   void getRank(String type ,String key ,int page,long randomkey);
   
   void getMainHotContent(int type ,int page ,long randomkey);
   
   int getDefultPageSize();


   
   // 非通信部分aidl
   void setVolume(float leftVolume, float rightVolume);  
}